summaryrefslogtreecommitdiffstats
path: root/src/HTTPServer/SslHTTPServerConnection.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/HTTPServer/SslHTTPServerConnection.h (renamed from src/HTTPServer/SslHTTPConnection.h)16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/HTTPServer/SslHTTPConnection.h b/src/HTTPServer/SslHTTPServerConnection.h
index b35bd8ba0..6032a2bd0 100644
--- a/src/HTTPServer/SslHTTPConnection.h
+++ b/src/HTTPServer/SslHTTPServerConnection.h
@@ -1,7 +1,7 @@
// SslHTTPConnection.h
// Declared the cSslHTTPConnection class representing a HTTP connection made over a SSL link
@@ -9,24 +9,24 @@
#pragma once
-#include "HTTPConnection.h"
+#include "HTTPServerConnection.h"
#include "PolarSSL++/BufferedSslContext.h"
-class cSslHTTPConnection :
- public cHTTPConnection
+class cSslHTTPServerConnection :
+ public cHTTPServerConnection
{
- typedef cHTTPConnection super;
+ typedef cHTTPServerConnection super;
public:
/** Creates a new connection on the specified server.
Sends the specified cert as the server certificate, uses the private key for decryption. */
- cSslHTTPConnection(cHTTPServer & a_HTTPServer, const cX509CertPtr & a_Cert, const cCryptoKeyPtr & a_PrivateKey);
+ cSslHTTPServerConnection(cHTTPServer & a_HTTPServer, const cX509CertPtr & a_Cert, const cCryptoKeyPtr & a_PrivateKey);
- ~cSslHTTPConnection();
+ ~cSslHTTPServerConnection();
protected:
cBufferedSslContext m_Ssl;
@@ -1,7 +1,7 @@
-// SslHTTPConnection.h
+// SslHTTPServerConnection.h
-// Declared the cSslHTTPConnection class representing a HTTP connection made over a SSL link
+// Declared the cSslHTTPServerConnection class representing a HTTP connection made over a SSL link
#pragma once